@@ -528,7 +528,6 @@ mount_smb_done_cb (GObject *object,
       g_object_unref (backend->mount_job);
     }  
   g_mutex_unlock (&backend->smb_mount_lock);
-  g_object_unref (backend);
 }
 
 static void
@@ -552,7 +551,7 @@ remount_smb (GVfsBackendNetwork *backend, GVfsJobMount *job)
   file = g_file_new_for_uri (workgroup);
 
   g_file_mount_enclosing_volume (file, G_MOUNT_MOUNT_NONE,
-                                 NULL, NULL, mount_smb_done_cb, g_object_ref (backend));
+                                 NULL, NULL, mount_smb_done_cb, backend);
   g_free (workgroup);
   g_object_unref (file);
 }
@@ -694,7 +693,7 @@ lookup_network_file (GVfsBackendNetwork *backend,
   out:
   g_vfs_job_failed (job, G_IO_ERROR,
 		    G_IO_ERROR_NOT_FOUND,
-		    _("File doesn't exist"));
+		    _("File doesn’t exist"));
 
   return NULL;
 }
@@ -849,7 +848,7 @@ try_create_monitor (GVfsBackend *backend,
     {
       g_vfs_job_failed (G_VFS_JOB (job), G_IO_ERROR,
 			G_IO_ERROR_NOT_SUPPORTED,
-			_("Can't monitor file or directory."));
+			_("Can’t monitor file or directory."));
       return TRUE;
     }
   
@@ -959,15 +958,9 @@ g_vfs_backend_network_finalize (GObject *object)
   g_object_unref (backend->workgroup_symbolic_icon);
   g_object_unref (backend->server_symbolic_icon);
   if (backend->smb_settings)
-    {
-      g_signal_handlers_disconnect_by_func (backend->smb_settings, smb_settings_change_event_cb, backend);
-      g_clear_object (&backend->smb_settings);
-    }
+    g_object_unref (backend->smb_settings);
   if (backend->dnssd_settings)
-    {
-      g_signal_handlers_disconnect_by_func (backend->dnssd_settings, dnssd_settings_change_event_cb, backend);
-      g_clear_object (&backend->dnssd_settings);
-    }
+    g_object_unref (backend->dnssd_settings);
   if (backend->dnssd_monitor)
     {
       g_signal_handlers_disconnect_by_func (backend->dnssd_monitor, notify_dnssd_local_changed, backend);
