@@ -82,13 +82,6 @@ struct _GVfsBackendSmb
 	
   gboolean password_in_keyring;
   GPasswordSave password_save;
-  
-  /* Cache */
-  char *cached_server_name;
-  char *cached_share_name;
-  char *cached_domain;
-  char *cached_username;
-  SMBCSRV *cached_server;
 };
 
 
@@ -318,118 +311,6 @@ auth_callback (SMBCCTX *context,
            backend->last_user, backend->last_domain);
 }
 
-/* Add a server to the cache system
- *
- * @param c         pointer to smb context
- * @param srv       pointer to server to add
- * @param server    server name 
- * @param share     share name
- * @param workgroup workgroup used to connect
- * @param username  username used to connect
- * @return          0 on success. 1 on failure.
- *
- */ 
-static int
-add_cached_server (SMBCCTX *context, SMBCSRV *new,
-		   const char *server_name, const char *share_name, 
-		   const char *domain, const char *username)
-{
-  GVfsBackendSmb *backend;
-
-  backend = smbc_getOptionUserData (context);
-  
-  if (backend->cached_server != NULL)
-    return 1;
-
-  backend->cached_server_name = g_strdup (server_name);
-  backend->cached_share_name = g_strdup (share_name);
-  backend->cached_domain = g_strdup (domain);
-  backend->cached_username = g_strdup (username);
-  backend->cached_server = new;
-
-  return 0;
-}
-
-/* Remove cached server
- *
- * @param c         pointer to smb context
- * @param srv       pointer to server to remove
- * @return          0 when found and removed. 1 on failure.
- *
- */ 
-static int
-remove_cached_server(SMBCCTX * context, SMBCSRV * server)
-{
-  GVfsBackendSmb *backend;
-
-  backend = smbc_getOptionUserData (context);
-  
-  if (backend->cached_server == server)
-    {
-      g_free (backend->cached_server_name);
-      backend->cached_server_name = NULL;
-      g_free (backend->cached_share_name);
-      backend->cached_share_name = NULL;
-      g_free (backend->cached_domain);
-      backend->cached_domain = NULL;
-      g_free (backend->cached_username);
-      backend->cached_username = NULL;
-      backend->cached_server = NULL;
-      return 0;
-    }
-  return 1;
-}
-
-
-/* Look up a server in the cache system
- *
- * @param c         pointer to smb context
- * @param server    server name to match
- * @param share     share name to match
- * @param workgroup workgroup to match
- * @param username  username to match
- * @return          pointer to SMBCSRV on success. NULL on failure.
- *
- */ 
-static SMBCSRV *
-get_cached_server (SMBCCTX * context,
-		   const char *server_name, const char *share_name,
-		   const char *domain, const char *username)
-{
-  GVfsBackendSmb *backend;
-
-  backend = smbc_getOptionUserData (context);
-
-  if (backend->cached_server != NULL &&
-      strcmp (backend->cached_server_name, server_name) == 0 &&
-      strcmp (backend->cached_share_name, share_name) == 0 &&
-      strcmp (backend->cached_domain, domain) == 0 &&
-      strcmp (backend->cached_username, username) == 0)
-    return backend->cached_server;
-
-  return NULL;
-}
-
-/* Try to remove all servers from the cache system and disconnect
- *
- * @param c         pointer to smb context
- *
- * @return          0 when found and removed. 1 on failure.
- *
- */ 
-static int
-purge_cached (SMBCCTX * context)
-{
-  GVfsBackendSmb *backend;
-  
-  backend = smbc_getOptionUserData (context);
-
-  if (backend->cached_server)
-    remove_cached_server(context, backend->cached_server);
-  
-  return 0;
-}
-
 #define SUB_DELIM_CHARS  "!$&'()*+,;="
 
 static gboolean
@@ -479,25 +360,11 @@ create_smb_uri_string (const char *server,
   GString *uri;
 
   uri = g_string_new ("smb://");
-  if (server == NULL)
-    return uri;
-
-  /* IPv6 server includes brackets in GMountSpec, smbclient doesn't */
-  if (server[0] == '[')
-    {
-      g_string_append_encoded (uri, server + 1, NULL);
-      g_string_truncate (uri, uri->len - 3);
-    }
-  else
-    g_string_append_encoded (uri, server, NULL);
-
+  g_string_append_encoded (uri, server, NULL);
   if (port != -1)
     g_string_append_printf (uri, ":%d", port);
   g_string_append_c (uri, '/');
-
-  if (share != NULL)
-    g_string_append_encoded (uri, share, NULL);
-
+  g_string_append_encoded (uri, share, NULL);
   if (path != NULL)
     {
       if (*path != '/')
@@ -512,7 +379,7 @@ create_smb_uri_string (const char *server,
   return uri;
 }
 
-char *
+static char *
 create_smb_uri (const char *server,
 		int port,
 		const char *share,
@@ -560,13 +427,7 @@ do_mount (GVfsBackend *backend,
 
   smbc_setDebug (smb_context, debug_val);
   smbc_setFunctionAuthDataWithContext (smb_context, auth_callback);
-  
-  smbc_setFunctionAddCachedServer (smb_context, add_cached_server);
-  smbc_setFunctionGetCachedServer (smb_context, get_cached_server);
-  smbc_setFunctionRemoveCachedServer (smb_context, remove_cached_server);
-  smbc_setFunctionPurgeCachedServers (smb_context, purge_cached);
 
-  /* FIXME: is strdup() still needed here? -- removed */
   if (op_backend->default_workgroup != NULL)
     smbc_setWorkgroup (smb_context, op_backend->default_workgroup);
 
@@ -579,11 +440,6 @@ do_mount (GVfsBackend *backend,
                                        op_backend->user != NULL);
   smbc_setOptionNoAutoAnonymousLogin (smb_context, TRUE);
 
-  
-#if 0
-  smbc_setOptionDebugToStderr (smb_context, 1);
-#endif
-  
   if (!smbc_init_context (smb_context))
     {
       g_vfs_job_failed (G_VFS_JOB (job),
@@ -685,8 +541,6 @@ do_mount (GVfsBackend *backend,
 
   if (res != 0)
     {
-      op_backend->mount_source = NULL;
-      
       if (op_backend->mount_cancelled) 
         g_vfs_job_failed (G_VFS_JOB (job),
 			  G_IO_ERROR, G_IO_ERROR_FAILED_HANDLED,
@@ -825,7 +679,7 @@ do_open_for_read (GVfsBackend *backend,
       if ((res == 0) && (S_ISDIR (st.st_mode)))
             g_vfs_job_failed (G_VFS_JOB (job),
                               G_IO_ERROR, G_IO_ERROR_IS_DIRECTORY,
-                             _("Can't open directory"));
+                             _("Can’t open directory"));
       else
         g_vfs_job_failed_from_errno (G_VFS_JOB (job), olderr);
   }
@@ -2053,7 +1907,7 @@ do_set_display_name (GVfsBackend *backend,
     {
       g_vfs_job_failed (G_VFS_JOB (job),
                         G_IO_ERROR, G_IO_ERROR_EXISTS,
-                        _("Can't rename file, filename already exists"));
+                        _("Can’t rename file, filename already exists"));
       goto out;
     }
 
@@ -2202,7 +2056,7 @@ do_move (GVfsBackend *backend,
 	      g_vfs_job_failed (G_VFS_JOB (job),
 				G_IO_ERROR,
 				G_IO_ERROR_WOULD_MERGE,
-				_("Can't move directory over directory"));
+				_("Can’t move directory over directory"));
 	      g_free (source_uri);
 	      g_free (dest_uri);
 	      return;
@@ -2274,7 +2128,7 @@ do_move (GVfsBackend *backend,
 	  (errsv == EINVAL && source_is_dir))
 	g_vfs_job_failed (G_VFS_JOB (job), 
 			  G_IO_ERROR, G_IO_ERROR_WOULD_RECURSE,
-			  _("Can't recursively move directory"));
+			  _("Can’t recursively move directory"));
       else
 	g_vfs_job_failed_from_errno (G_VFS_JOB (job), errsv);
     }
