@@ -845,11 +845,6 @@ gvfs_udisks2_volume_is_network_class (GVfsUDisks2Volume *volume)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-/* can remove this once we depend on gio >= 2.31.19 */
-#ifndef G_VOLUME_IDENTIFIER_KIND_CLASS
-#define G_VOLUME_IDENTIFIER_KIND_CLASS "class"
-#endif
-
 static gchar *
 gvfs_udisks2_volume_get_identifier (GVolume      *_volume,
                                     const gchar  *kind)
@@ -1298,7 +1293,7 @@ on_mount_operation_reply (GMountOperation       *mount_operation,
             {
               UDisksObject *object;
 
-              object = g_dbus_interface_get_object (G_DBUS_INTERFACE (cleartext_block));
+              object = UDISKS_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (cleartext_block)));
               g_object_unref (cleartext_block);
               if (object != NULL)
                 {
